pysign
======

`pysign` is a tool for signing Python package distributions.

This project is developed by [Trail of Bits](https://www.trailofbits.com/) with
support from Google. This is not an official Google product.
